Class: Aws::WorkspacesInstances::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkspacesInstances::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workspacesinstances/client.rb,
sig/client.rbs
Overview
An API client for WorkspacesInstances. To construct a client, you need to configure a :region and :credentials.
client = Aws::WorkspacesInstances::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AssociateVolumeResponseSuccess, _CreateVolumeResponseSuccess, _CreateWorkspaceInstanceResponseSuccess, _DeleteVolumeResponseSuccess, _DeleteWorkspaceInstanceResponseSuccess, _DisassociateVolumeResponseSuccess, _GetWorkspaceInstanceResponseSuccess, _ListInstanceTypesResponseSuccess, _ListRegionsResponseSuccess, _ListTagsForResourceResponseSuccess, _ListWorkspaceInstancesResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_volume(params = {}) ⇒ Struct
Attaches a volume to a WorkSpace Instance.
-
#create_volume(params = {}) ⇒ Types::CreateVolumeResponse
Creates a new volume for WorkSpace Instances.
-
#create_workspace_instance(params = {}) ⇒ Types::CreateWorkspaceInstanceResponse
Launches a new WorkSpace Instance with specified configuration parameters, enabling programmatic workspace deployment.
-
#delete_volume(params = {}) ⇒ Struct
Deletes a specified volume.
-
#delete_workspace_instance(params = {}) ⇒ Struct
Deletes the specified WorkSpace.
-
#disassociate_volume(params = {}) ⇒ Struct
Detaches a volume from a WorkSpace Instance.
-
#get_workspace_instance(params = {}) ⇒ Types::GetWorkspaceInstanceResponse
Retrieves detailed information about a specific WorkSpace Instance.
-
#list_instance_types(params = {}) ⇒ Types::ListInstanceTypesResponse
Retrieves a list of instance types supported by Amazon WorkSpaces Instances, enabling precise workspace infrastructure configuration.
-
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Retrieves a list of AWS regions supported by Amazon WorkSpaces Instances, enabling region discovery for workspace deployments.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves tags for a WorkSpace Instance.
-
#list_workspace_instances(params = {}) ⇒ Types::ListWorkspaceInstancesResponse
Retrieves a collection of WorkSpaces Instances based on specified filters.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a WorkSpace Instance.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a WorkSpace Instance.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1196 1197 1198 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1196 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1199 1200 1201 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1199 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#associate_volume(params = {}) ⇒ Struct
Attaches a volume to a WorkSpace Instance.
86 |
# File 'sig/client.rbs', line 86
def associate_volume: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1169 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WorkspacesInstances') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-workspacesinstances' context[:gem_version] = '1.18.0' Seahorse::Client::Request.new(handlers, context) end |
#create_volume(params = {}) ⇒ Types::CreateVolumeResponse
Creates a new volume for WorkSpace Instances.
98 |
# File 'sig/client.rbs', line 98
def create_volume: (
|
#create_workspace_instance(params = {}) ⇒ Types::CreateWorkspaceInstanceResponse
Launches a new WorkSpace Instance with specified configuration parameters, enabling programmatic workspace deployment.
127 |
# File 'sig/client.rbs', line 127
def create_workspace_instance: (
|
#delete_volume(params = {}) ⇒ Struct
Deletes a specified volume.
316 |
# File 'sig/client.rbs', line 316
def delete_volume: (
|
#delete_workspace_instance(params = {}) ⇒ Struct
Deletes the specified WorkSpace
Usage of this API will result in deletion of the resource in question.
325 |
# File 'sig/client.rbs', line 325
def delete_workspace_instance: (
|
#disassociate_volume(params = {}) ⇒ Struct
Detaches a volume from a WorkSpace Instance.
334 |
# File 'sig/client.rbs', line 334
def disassociate_volume: (
|
#get_workspace_instance(params = {}) ⇒ Types::GetWorkspaceInstanceResponse
Retrieves detailed information about a specific WorkSpace Instance.
352 |
# File 'sig/client.rbs', line 352
def get_workspace_instance: (
|
#list_instance_types(params = {}) ⇒ Types::ListInstanceTypesResponse
Retrieves a list of instance types supported by Amazon WorkSpaces Instances, enabling precise workspace infrastructure configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
363 |
# File 'sig/client.rbs', line 363
def list_instance_types: (
|
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Retrieves a list of AWS regions supported by Amazon WorkSpaces Instances, enabling region discovery for workspace deployments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
380 |
# File 'sig/client.rbs', line 380
def list_regions: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves tags for a WorkSpace Instance.
391 |
# File 'sig/client.rbs', line 391
def list_tags_for_resource: (
|
#list_workspace_instances(params = {}) ⇒ Types::ListWorkspaceInstancesResponse
Retrieves a collection of WorkSpaces Instances based on specified filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
402 |
# File 'sig/client.rbs', line 402
def list_workspace_instances: (
|
#tag_resource(params = {}) ⇒ Struct
Adds tags to a WorkSpace Instance.
413 |
# File 'sig/client.rbs', line 413
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from a WorkSpace Instance.
428 |
# File 'sig/client.rbs', line 428
def untag_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1189 1190 1191 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1189 def waiter_names [] end |