Class: Aws::WorkspacesInstances::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::WorkspacesInstances::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-workspacesinstances/client.rb
Overview
An API client for WorkspacesInstances. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::WorkspacesInstances::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_volume(params = {}) ⇒ Struct
Attaches a volume to a WorkSpace Instance.
-
#create_volume(params = {}) ⇒ Types::CreateVolumeResponse
Creates a new volume for WorkSpace Instances.
-
#create_workspace_instance(params = {}) ⇒ Types::CreateWorkspaceInstanceResponse
Launches a new WorkSpace Instance with specified configuration parameters, enabling programmatic workspace deployment.
-
#delete_volume(params = {}) ⇒ Struct
Deletes a specified volume.
-
#delete_workspace_instance(params = {}) ⇒ Struct
Deletes the specified WorkSpace.
-
#disassociate_volume(params = {}) ⇒ Struct
Detaches a volume from a WorkSpace Instance.
-
#get_workspace_instance(params = {}) ⇒ Types::GetWorkspaceInstanceResponse
Retrieves detailed information about a specific WorkSpace Instance.
-
#list_instance_types(params = {}) ⇒ Types::ListInstanceTypesResponse
Retrieves a list of instance types supported by Amazon WorkSpaces Instances, enabling precise workspace infrastructure configuration.
-
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Retrieves a list of AWS regions supported by Amazon WorkSpaces Instances, enabling region discovery for workspace deployments.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves tags for a WorkSpace Instance.
-
#list_workspace_instances(params = {}) ⇒ Types::ListWorkspaceInstancesResponse
Retrieves a collection of WorkSpaces Instances based on specified filters.
-
#tag_resource(params = {}) ⇒ Struct
Adds tags to a WorkSpace Instance.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from a WorkSpace Instance.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1196 1197 1198 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1196 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1199 1200 1201 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1199 def errors_module Errors end |
Instance Method Details
#associate_volume(params = {}) ⇒ Struct
Attaches a volume to a WorkSpace Instance.
509 510 511 512 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 509 def associate_volume(params = {}, = {}) req = build_request(:associate_volume, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1169 1170 1171 1172 1173 1174 1175 1176 1177 1178 1179 1180 1181 1182 1183 1184 1185 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1169 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::WorkspacesInstances') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-workspacesinstances' context[:gem_version] = '1.16.0' Seahorse::Client::Request.new(handlers, context) end |
#create_volume(params = {}) ⇒ Types::CreateVolumeResponse
Creates a new volume for WorkSpace Instances.
586 587 588 589 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 586 def create_volume(params = {}, = {}) req = build_request(:create_volume, params) req.send_request() end |
#create_workspace_instance(params = {}) ⇒ Types::CreateWorkspaceInstanceResponse
Launches a new WorkSpace Instance with specified configuration parameters, enabling programmatic workspace deployment.
812 813 814 815 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 812 def create_workspace_instance(params = {}, = {}) req = build_request(:create_workspace_instance, params) req.send_request() end |
#delete_volume(params = {}) ⇒ Struct
Deletes a specified volume.
834 835 836 837 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 834 def delete_volume(params = {}, = {}) req = build_request(:delete_volume, params) req.send_request() end |
#delete_workspace_instance(params = {}) ⇒ Struct
Deletes the specified WorkSpace
Usage of this API will result in deletion of the resource in question.
858 859 860 861 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 858 def delete_workspace_instance(params = {}, = {}) req = build_request(:delete_workspace_instance, params) req.send_request() end |
#disassociate_volume(params = {}) ⇒ Struct
Detaches a volume from a WorkSpace Instance.
892 893 894 895 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 892 def disassociate_volume(params = {}, = {}) req = build_request(:disassociate_volume, params) req.send_request() end |
#get_workspace_instance(params = {}) ⇒ Types::GetWorkspaceInstanceResponse
Retrieves detailed information about a specific WorkSpace Instance.
935 936 937 938 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 935 def get_workspace_instance(params = {}, = {}) req = build_request(:get_workspace_instance, params) req.send_request() end |
#list_instance_types(params = {}) ⇒ Types::ListInstanceTypesResponse
Retrieves a list of instance types supported by Amazon WorkSpaces Instances, enabling precise workspace infrastructure configuration.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
989 990 991 992 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 989 def list_instance_types(params = {}, = {}) req = build_request(:list_instance_types, params) req.send_request() end |
#list_regions(params = {}) ⇒ Types::ListRegionsResponse
Retrieves a list of AWS regions supported by Amazon WorkSpaces Instances, enabling region discovery for workspace deployments.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1028 1029 1030 1031 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1028 def list_regions(params = {}, = {}) req = build_request(:list_regions, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Retrieves tags for a WorkSpace Instance.
1058 1059 1060 1061 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1058 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#list_workspace_instances(params = {}) ⇒ Types::ListWorkspaceInstancesResponse
Retrieves a collection of WorkSpaces Instances based on specified filters.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1103 1104 1105 1106 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1103 def list_workspace_instances(params = {}, = {}) req = build_request(:list_workspace_instances, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds tags to a WorkSpace Instance.
1134 1135 1136 1137 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1134 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from a WorkSpace Instance.
1160 1161 1162 1163 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1160 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1189 1190 1191 |
# File 'lib/aws-sdk-workspacesinstances/client.rb', line 1189 def waiter_names [] end |